@@ -1,6 +1,6 @@
 package ShardedKV::Storage::Redis::String;
 {
-  $ShardedKV::Storage::Redis::String::VERSION = '0.16';
+  $ShardedKV::Storage::Redis::String::VERSION = '0.17';
 }
 use Moose;
 # ABSTRACT: Storing simple string values in Redis
@@ -27,7 +27,7 @@ sub get {
       endpoint => $endpoint,
       key => $key,
       storage_type => 'redis',
-      message => "Failed to fetch key ($key) from Redis ($endpoint): @_",
+      message => "Failed to fetch key ($key) from Redis ($endpoint): $@",
     });
   };
   
@@ -43,8 +43,10 @@ sub set {
   my ($self, $key, $value_ref) = @_;
   my $r = $self->redis;
 
-  my $rv = eval {
-    $r->set($key, $$value_ref);
+  my $rv;
+  eval {
+    $rv = $r->set($key, $$value_ref);
+    1;
   } or do {
     my $endpoint = $self->redis_connect_str;
     ShardedKV::Error::WriteFail->throw({
@@ -52,7 +54,7 @@ sub set {
       key => $key,
       storage_type => 'redis',
       operation => 'set',
-      message => "Failed to store key ($key) to Redis ($endpoint): @_",
+      message => "Failed to store key ($key) to Redis ($endpoint): $@",
     });
   };
 
@@ -70,7 +72,7 @@ sub set {
         key => $key,
         storage_type => 'redis',
         operation => 'expire',
-        message => "Failed to store key ($key) to Redis ($endpoint): @_",
+        message => "Failed to store key ($key) to Redis ($endpoint): $@",
       });
     };
   }
@@ -91,7 +93,7 @@ ShardedKV::Storage::Redis::String - Storing simple string values in Redis
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
